#
# spec file for package release-notes-ha
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define SUSE_PROD SUSE_Linux_Enterprise_High_Availability_Extension_15
# "lifecycle" changes the document profiling, accepted values:
#   beta | maintained | unmaintained
%define lifecycle maintained
%define reponame release-notes-sle-ha
Name:           release-notes-ha
Version:        15.6.20240417
Release:        150600.3.3.4
Summary:        Release Notes for SUSE Linux Enterprise High Availability Extension
License:        CC-BY-ND-4.0
Group:          Documentation/SUSE
URL:            https://www.suse.com/releasenotes/
Source:         %{reponame}-%{version}.tar.bz2
BuildRequires:  daps
BuildRequires:  suse-xsl-stylesheets >= 1.9.18
BuildRequires:  update-desktop-files
BuildRequires:  w3m
Requires:       dejavu-fonts
Requires:       google-opensans-fonts
Provides:       release-notes() = sle-ha
#FIXME!
Provides:       release-notes-hae = 12
Obsoletes:      release-notes-hae < 12
BuildArch:      noarch

%description
This package contains the release notes for SUSE Linux Enterprise High
Availability Extension. After installing this package, the release notes
files can be found in the %{_datadir}/doc/release-notes directory. The release
notes are available in the following output formats: PDF, HTML, and TXT.

%prep
%setup -q -n %{reponame}-%{version}

%build
sed -i 's/@VERSION@/%{version}/' adoc/release-notes-docinfo.xml adoc/attributes-generic.adoc
%make_build all LIFECYCLE=%{lifecycle}

%install
rnpath=%{buildroot}%{_datadir}/doc/release-notes/%{SUSE_PROD}
install -m 0644 -D LICENSE ${rnpath}/LICENSE
install -m 0644 -D "build/release-notes/html/release-notes/index.html" "${rnpath}/RELEASE-NOTES.en.html"
install -m 0644 -D "build/release-notes/html/release-notes/changelog.html" "${rnpath}/changelog.html"
cp -R "build/release-notes/single-html/release-notes/static/" "${rnpath}"
install -m 0644 -D "build/release-notes/yast-html/release-notes.html" "${rnpath}/RELEASE-NOTES.en.rtf"
install -m 0644 -D "build/release-notes/release-notes_color_en.pdf" "${rnpath}/RELEASE-NOTES.en.pdf"
install -m 0644 -D "build/release-notes/release-notes.txt" "${rnpath}/RELEASE-NOTES.en.txt"

%files
%doc %{_datadir}/doc/release-notes/

%changelog
* Wed Jun 12 2024 lukas.kucharczyk@suse.com
- 15.6.20240612 (tracked in bsc#933411)
- Set to maintained
* Wed Apr 17 2024 lukas.kucharczyk@suse.com
- 15.6.20240417 (tracked in bsc#933411)
- Updated attributes (jsc#DOCTEAM-1133)
* Wed Feb 21 2024 lukas.kucharczyk@suse.com
- 15.6.20240221 (tracked in bsc#933411)
- Fixed updated crm cluster commands (jsc#DOCTEAM-1261)
* Thu Oct 19 2023 lukas.kucharczyk@suse.com
- 15.6.20231019 (tracked in bsc#933411)
- Initial 15 SP6 version
- Added note about removed Nagios plugins (jsc#SLE-3877)
- Removed Geo Clustering for X reference (jsc#DOCTEAM-1087)
* Wed May 10 2023 lukas.kucharczyk@suse.com
- 15.5.20230510 (tracked in bsc#933411)
- Added note about rear27a (jsc#PED-960)
* Wed Jan  4 2023 lukas.kucharczyk@suse.com
- 15.5.20230104 (tracked in bsc#933411)
- Added note about removal of pssh (jsc#DOCTEAM-862)
* Wed Nov 30 2022 lukas.kucharczyk@suse.com
- 15.5.20221130 (tracked in bsc#933411)
- Fix product version
* Tue Oct 18 2022 lukas.kucharczyk@suse.com
- 15.5.20221018 (tracked in bsc#933411)
- Initial version
- Added note about defragfs.ocfs2 (bsc#1203444)
* Wed May 11 2022 lukas.kucharczyk@suse.com
- 15.4.20220511 (tracked in bsc#933411)
- Added changelog
* Thu Apr 21 2022 lukas.kucharczyk@suse.com
- 15.4.20220421 (tracked in bsc#933411)
- Add note about HAProxy legacy HTTP mode
* Wed Mar 23 2022 lukas.kucharczyk@suse.com
- 15.4.20220323 (tracked in bsc#933411)
- Added note about deprecating ha-cluster-* (jsc#SLE-23019)
- Added note about crmsh --all parameter (jsc#SLE-22493)
* Wed Feb 16 2022 lukas.kucharczyk@suse.com
- 15.4.20220216 (tracked in bsc#933411)
- Added note about hb_report deprecation (jsc#SLE-21746)
- Added OCFS2 nocluster note (jsc#SLE-22506)
* Wed Nov  3 2021 lukas.kucharczyk@suse.com
- 15.4.20211103 (tracked in bsc#933411)
- Initial SP4 version
* Wed May  5 2021 lukas.kucharczyk@suse.com
- 15.3.20210505 (tracked in bsc#933411)
- Updated branding (jsc#SLE-14772)
* Tue Nov 17 2020 sknorr@suse.com
- 15.3.20201117 (bsc#933411)
- Initial releas notes for SLE-HA 15 SP3
* Fri Jun  5 2020 sknorr@suse.com
- 15.2.20200605 (bsc#933411)
- Update displayed release date of product
* Fri May  8 2020 sknorr@suse.com
- 15.2.20200508
- Added note about crm cluster stop (bsc#1155609)
- Added note about Terminology Change in Upgrade Documentation
  (bsc#1150382)
- Added note about removal of lvm2-cmirrord and lvm2-clvm
  (jsc#SLE-9163)
- Added a link to SLE module overview
* Tue Feb  4 2020 sknorr@suse.com
- 15.2.20200204 (tracked in bsc#933411)
- Initial notes for SLE-HA 15 SP2
- Migrate to AsciiDoc as source format
* Fri Sep 28 2018 sknorr@suse.com
- 15.1.20180928 (tracked in bsc#933411)
- Updated Makefile
- Updated template text
- Updated release notes from FATE
* Tue Jul 17 2018 sknorr@suse.com
- 15.0.20180717 (tracked in bsc#1101526)
- Updated release notes from FATE
- Changed notes:
  - Hawk Data Files Installed to /usr/share/hawk (FATE#321020)
    [restored path to data files that was lost in broken prior
    edit, wording improvements]
  - SCSI Locking on Multipath With mpathpersist Resource Agent
    (FATE#324044)
    [formatting fix]
  - Probing Guest Nodes for Resource Status (FATE#324441)
    [formatting and wording improvements]
* Tue Jun  5 2018 sknorr@suse.com
- Added provides to fix Release Notes display in installer
  (bsc#1054478)
* Fri May 18 2018 sknorr@suse.com
- 15.0.20180518 (15.0 GM)
- Updated release notes from FATE
- New entries:
  - SCSI Locking on Multipath With mpathpersist Resource Agent
    (FATE#324044)
- Changed entries:
  - Probing Guest Nodes for Resource Status (FATE#324441)
* Fri Apr 27 2018 sknorr@suse.com
- 15.0.20180427
- Updated release notes from FATE
- New entries:
  - Probing Guest Nodes for Resource Status (FATE#324441)
* Mon Apr  9 2018 sknorr@suse.com
- 15.0.20180409
- Updated release notes from FATE
- Changed entries:
  - IPVS Has Been Moved From the HA Extension to the Base OS
    (FATE#321936, bsc#1084464): Fix typo
* Mon Feb 12 2018 sknorr@suse.com
- 15.0.20180212
- Updated template text
- Updated release notes from FATE
- New entries:
  - Hawk Data Files Installed to /usr/share/hawk (FATE#321020)
  - QDevice/QNetd Support for Corosync Quorum Device (FATE#321385)
  - crm Report (hb_report) Configuration File (FATE#321640)
  - IPVS Has Been Moved From the HA Extension to the Base OS
    (FATE#321936)
  - Support for Manual Tickets in Geo Clustering (FATE#322100)
  - Clustering Support for MD RAID10 Devices (FATE#323171)
  - Container Bundles (FATE#323415)
  - AutoYaST Support for Geo Clustering (FATE#323863)
* Tue Aug 22 2017 sknorr@suse.com
- 15.0.20170821
- Updated Makefile
- Updated template text
- Updated release notes from FATE
* Thu Jul  6 2017 sknorr@suse.com
- 12.3.20170706
- Updated release notes from FATE
- Changed entries:
  - DRBD Has Been Updated to Version 9.0.8 (FATE#323128)
    [We ship DRBD 9.0.8, not 9.0.7]
* Fri Jun 23 2017 sknorr@suse.com
- 12.3.20170623
- Updated release notes from FATE
- New entries:
  - Support for Online Size Change in cluster-md (Cluster Multi-Device)
    (FATE#320864)
  - Fencing Agent for Azure (FATE#321105)
  - Bug Fixes in Corosync 2.4.x Have Been Backported to 2.3.6
    (FATE#322113)
  - DRBD Has Been Updated to Version 9.0.7 (FATE#323128)
* Wed May 24 2017 sknorr@suse.com
- 12.3.20170524
- Updated release notes from FATE
- New entries:
  - Support for Watchdog-only Fencing Using SBD (FATE#321017)
  - Creating and Editing Pacemaker Alerts in Hawk (FATE#321118)
  - ocfs2-tools Has Been Updated to 1.8.5 (FATE#322956)
* Fri Apr 28 2017 sknorr@suse.com
- 12.3.20170428
- Updated template text
  - Added planned release date (September 2017)
- Updated release notes from FATE
- New entries:
  - Hawk: New Wizard Shows Differences in Software Package Versions
    Between Nodes (FATE#320848)
  - Hawk: Wizard to Verify Cluster Health and Configuration
    (FATE#320866)
  - Hawk: Editing Fencing Topologies (FATE#321133)
* Fri Mar 31 2017 sknorr@suse.com
- 12.3.20170331
- Updated release notes from FATE
- New entries:
  - Hawk: Detection of Unexpected DRBD Resource Status
    (FATE#322043)
* Tue Nov 15 2016 sknorr@suse.com
- Replace @VERSION@ with version number (bsc#1009221)
* Thu Nov 10 2016 sknorr@suse.com
- 12.3.20161110 (bsc#933411)
- Updated template text
* Fri Oct  7 2016 sknorr@suse.com
- 12.2.20161007
- Updated release notes from FATE
- New entries:
  - FATE#320757: Documentation for SLE HA 12 SP2 and SLE HA GEO 12
    SP2
* Fri Sep 16 2016 sknorr@suse.com
- 12.2.20160916
- Updated template text
- Updated release notes from FATE
- New entries:
  - FATE#321209: DRBD 9 Automatic Resource Promotion
* Fri Aug 26 2016 sknorr@suse.com
- 12.2.20160826 (for 12 SP2 RC2)
- Updated template text
- Updated release notes from FATE
- New entries:
  - FATE#320855: Pacemaker Can Trigger Action Based on Event (Alert
    Agent)
- Removed entries:
  - FATE#320467: Cluster Support and HA Capability for POWER
    (Now published in SLES release notes only)
  - FATE#321013: Data Synchronization Across Geo Clusters Using Stacked
    DRBD devices
    (Now published in SLE HA Geo release notes only)
* Thu Aug  4 2016 sknorr@suse.com
- 12.2.20160804
- Updated Makefile from repository
- Updated template text
- Updated release notes from FATE
- New entries:
  - FATE#320399: Converting Metadata to the DRBD 9 Format When Migrating
  - FATE#320467: Cluster Support and HA Capability for POWER
  - FATE#321013: Data Synchronization Across Geo Clusters Using Stacked
    DRBD devices
* Fri Jul  1 2016 sknorr@suse.com
- 12.2.20160701
- Updated Makefile from repository
- Updated release notes from FATE
- New entries:
  - FATE#320814: IPv6 Support in ldirectord
- Changed entries:
  - Updated entries to new categories, small textual changes
* Wed May  4 2016 sknorr@suse.com
- 12.2.20160504
- Initial release for SLEHA 12 SP2
- Updated release notes from FATE
- New entries:
  FATE#320560, FATE#319665, FATE#318806, FATE#320420,
  FATE#318320, FATE#318318, FATE#320605, FATE#320604,
  FATE#320495, FATE#320401, FATE#320389, FATE#319332,
  FATE#320607, FATE#315096, FATE#320561
* Wed Apr 20 2016 sknorr@suse.com
- 12.1.20160420 (bsc#976431):
- Set correct product version, so we don't ship SES RN.
- Update Makefile from central repo.
- Update release notes from FATE
  - All entries coming from FATE are new, because we now ship
    entries for the correct product
* Wed Oct 28 2015 ke@suse.de
- 12.1.20151028 (bsc#952393):
- Fix encoding of yast-html.
* Thu Oct  8 2015 ke@suse.de
- 12.1.20151008 (bsc#933411):
- Update release notes from FATE.
* Mon Sep 14 2015 ke@suse.de
- 12.1.20150914 (bsc#938049):
- Update release notes from FATE.
- Fix encoding of .txt.
* Tue Jul 14 2015 ke@suse.de
- 12.1.20150714 (bsc#933411):
- More 12 SP1 adjustments.
- Update release notes from FATE.
* Tue Jun  2 2015 ke@suse.de
- 12.0.20150602 (bsc#933411):
- Starting with SP1.
- Update release notes from FATE.
* Wed Nov 12 2014 ke@suse.de
- 12.0.20141112 (bnc#904680):
- Replace Novell with SUSE (some leftovers); bnc#904680.
- Fix documentation URL.
* Mon Sep 29 2014 ke@suse.de
- 12.0.20140929:
- Update release notes from FATE.
- New entry: What's New? (bnc#898123).
* Thu Sep 25 2014 ke@suse.de
- 12.0.20140925:
- Update release notes from FATE.
* Wed Sep 17 2014 ke@suse.de
- 12.0.20140917:
- Update release notes from FATE.
- Temporarily collect unclassified entries as "Miscellaneous".
* Thu Sep  4 2014 ke@suse.de
- 12.0.20140904:
- Update release notes from FATE.
* Thu Aug 28 2014 ke@suse.de
- 12.0.20140828:
- Update release notes from FATE.
* Thu Aug 21 2014 ke@suse.de
- 12.0.20140821:
- Update release notes from FATE.
* Mon Aug  4 2014 rsalevsky@suse.com
- 12.0.20140804:
  * change date format
  * fix wrong version
* Thu Jul 24 2014 rsalevsky@suse.com
- 12.0.20140724:
  * Update release notes from FATE
  * New Makefile
* Wed Jul 23 2014 ro@suse.de
- rename from release-notes-hae to release-notes-ha
* Thu Jul  3 2014 ke@suse.de
- 12.0.12:
- Update release notes from FATE.
- Switch to article layout.
* Thu Jun 12 2014 ke@suse.de
- 12.0.10:
- Update release notes from FATE.
* Mon Jun  2 2014 ke@suse.de
-12.0.8:
- Update release notes from FATE.
* Wed Apr 30 2014 ke@suse.de
- 12.0.8:
- Update release notes from FATE.
* Wed Apr 16 2014 rsalevsky@suse.com
- 12.0.7
- Update release notes from FATE.
- Cleanup specfile and fix build warning.
* Mon Apr  7 2014 ke@suse.de
- 12.0.6:
- Update release notes from FATE.
* Thu Mar 27 2014 ke@suse.de
- 12.0.5:
- Update release notes from FATE.
* Thu Mar 13 2014 ke@suse.de
- 12.0.4:
- Update SP3 release notes from FATE.
- Require dejavu-fonts and google-opensans-fonts.
* Wed Mar  5 2014 ke@suse.de
- 12.0.3:
- Update SP3 release notes from FATE.
- Avoid superfluous directory in release-notes-static (bnc#866876).
* Thu Feb 27 2014 ke@suse.de
  12.0.2:
- Update SP3 release notes from FATE.
- Use yast.xsl to avoid setting docbook default
  body.attributes (bnc#864900).
* Wed Feb 12 2014 ke@suse.de
- 12.0.1:
- Update SLEHA 12 release notes from FATE.
- Remove misleading provides/obsoletes.
* Tue Feb 11 2014 ke@suse.de
- 12.0.0 (bnc#862084):
- Import SLEHA 12 release notes from FATE.
* Tue Jul 30 2013 ke@suse.de
- 11.3.17:
- Update SP3 release notes from FATE.
- Fix xml/Makefile.am to build .txt output; bnc#831635.
* Thu Jul 11 2013 ke@suse.de
- 11.3.16:
- Update SP3 release notes from FATE.
- Fix macro expansion for product title; bnc#829060.
* Tue Jul  2 2013 ke@suse.de
- 11.3.15:
- Update SP3 release notes from FATE.
- Update info on the docs; bnc#826887.
* Tue Jun 18 2013 ke@suse.de
- 11.3.14:
- Update SP3 release notes from FATE.
- Minor, mostly cosmetic adjustments.
* Mon May 27 2013 ke@suse.de
- 11.3.13:
- Update SP3 release notes from FATE.
- Additional target (release-notes-static) for publishing on the Web
  using daps; bnc#821574.
- Use daps to build the PDF output format.
* Thu May 23 2013 ke@suse.de
- 11.3.12:
- Update SP3 release notes from FATE.
* Thu May 16 2013 ke@suse.de
- 11.3.11:
- Update SP3 release notes from FATE.
* Wed May  8 2013 ke@suse.de
- 11.3.10:
- Update SP3 release notes from FATE.
- Updated entries: Samba CTDB Cluster Rolling Update Support
  (bnc#818580).
* Mon Apr 29 2013 ke@suse.de
- 11.3.9:
- Update SP3 release notes from FATE.
* Thu Apr 18 2013 ke@suse.de
- 11.3.8:
- Update SP3 release notes from FATE (now also with fates in state
  validation).
* Mon Apr 15 2013 ke@suse.de
- 11.3.7:
- Update SP3 release notes from FATE.
* Thu Apr  4 2013 ke@suse.de
- 11.3.6:
- Update SP3 release notes from FATE.
* Thu Mar 28 2013 ke@suse.de
- 11.3.5:
- Pull in SP3 release notes from FATE.
* Thu Mar 21 2013 ke@suse.de
- 11.3.4:
- Pull in SP3 release notes from FATE.
* Wed Mar 13 2013 ke@suse.de
- 11.3.3:
- Pull in SP3 release notes from FATE.
- Add more section for entries imported from FATE.
- 11.3.2:
- Pull in SP3 release notes from FATE.
- Build and ship the PDF output format.
- Add more section for entries imported from FATE.
* Tue Feb  5 2013 ke@suse.de
- 11.3.1:
- Pull in SP3 release notes from FATE.
- Improve document structure.
* Wed Jan  2 2013 ke@suse.de
- 11.3.0:
- Pull in SP3 release notes from FATE.
* Fri Feb  3 2012 lmb@novell.com
- Update release notes for SLE HA 11 SP2 GMC.
* Fri Jul  1 2011 lmb@novell.com
- Update for SLE HA 11 SP2.
* Wed Feb  9 2011 lmb@novell.com
- Include reference to ACL functionality (see
  /usr/share/doc/packages/pacemaker/acls.txt)
- Clarify that mixed endian clusters are not supported.
- Include information on updated CTDB integration.
* Wed Aug 11 2010 lmb@novell.com
- Update for first maintenance update.
- Update note on KVM/qemu/VNC autoport selection; the issue in kvm/qemu
  is now fixed, so it will work, but is still not recommended.
- Added small note on CTDB resource agent parameters.
* Wed May 12 2010 lmb@novell.com
- Update for GM.
* Mon May 10 2010 lmb@novell.com
- Update release notes for GMC.
* Tue Apr 27 2010 lmb@novell.com
- Update release notes for RC4.
* Mon Apr 12 2010 lmb@novell.com
- Prepare release notes for release candidate 3. Major overhaul,
  includes new sections and highlights SP1 features and changes.
* Mon Jan 11 2010 lmb@novell.com
- Add note about OCFS2's support status in combination with Oracle RAC.
* Mon Dec 14 2009 "lmb@novell.com"
- Minimal changes to reflect new version.
* Fri Dec 11 2009 "lmb@novell.com"
- Initial commit for SP1.
* Thu Mar 19 2009 ihno@suse.de
- added comment from kim kerry
* Wed Mar 11 2009 ihno@suse.de
- added snipped from bnc#479483
* Thu Feb 12 2009 ihno@suse.de
- Adjusted Releaase Notes as requested in bug bnc#474656
* Wed Feb 11 2009 ihno@suse.de
- Changed Product and version name
* Tue Feb 10 2009 ro@suse.de
- fix xml error to fix build
* Tue Feb  3 2009 ihno@suse.de
- added snipped from bnc#467996
* Mon Jan 12 2009 ro@suse.de
- rename to release-notes-hae
* Mon Dec  8 2008 kukuk@suse.de
- Adjust name of directory [bnc#456049]
* Mon Oct 20 2008 ro@suse.de
- fix dir for tarball
* Mon Oct 20 2008 ihno@suse.de
- Initial version for SLES HASI
